@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow::Pom;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION = 0.96007;
+our $VERSION = 0.96008;
 our $workflow = App::Git::Workflow::Pom->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -147,7 +147,7 @@ git-pom - Manage pom.xml file versions
 
 =head1 VERSION
 
-This documentation refers to git-pom version 0.96007
+This documentation refers to git-pom version 0.96008
 
 =head1 SYNOPSIS
 
@@ -161,6 +161,8 @@ This documentation refers to git-pom version 0.96007
   whos          Which branch uses the pom version "version"
 
  OPTIONS:
+  -P --pom[=]file
+                Specify the pom file location (Default pom.xml)
   -u --update   Update to next version (used with next)
   -t --tag[=]str
                 Specify a tag that any branch with newer commits must contain
