@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.96007;
+our $VERSION  = 0.96008;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -35,6 +35,7 @@ sub run {
         'pull_options|pull-options|P=s',
         'file|f=s',
         'max|m=i',
+        'runs|R=i',
         'once|1',
         'quiet|q',
         'remote|r',
@@ -43,7 +44,7 @@ sub run {
 
     # do stuff here
     my $action = @ARGV && $actions{$ARGV[0]} ? shift @ARGV : @ARGV ? 'do' : 'show';
-    my $once   = $option{once} ? -1 : 1;
+    my $once   = $option{once} ? -1 : -$option{runs} || 1;
     my ($last) = git_state();
 
     while ($once) {
@@ -172,7 +173,7 @@ git-watch - Watch for changes in repository up-stream
 
 =head1 VERSION
 
-This documentation refers to git-watch version 0.96007
+This documentation refers to git-watch version 0.96008
 
 =head1 SYNOPSIS
 
@@ -185,6 +186,8 @@ This documentation refers to git-watch version 0.96007
 
  OPTIONS:
   -1 --once     Run once then exit
+  -R --runs[=]int
+                Run at most this number of times.
   -p --pull     Before checking if anything has changed do a git pull to the
                 current branch. (see notes below)
   -P --pull-options[=]flags
