@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 
-our $VERSION     = 0.96007;
+our $VERSION     = 0.96008;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -59,6 +59,7 @@ sub AUTOLOAD {
     }
     push @{ $self->{ran} }, $cmd;
 
+    confess "Data not set up correctly! Not an ARRAY of HASHes\n" if ref $self->{data}    ne "ARRAY";
     confess "Data not set up correctly! Not an Array of Hashes\n" if ref $self->{data}[0] ne "HASH";
     my ($action, $return) = each %{ shift @{ $self->{data} } };
 
@@ -72,7 +73,9 @@ sub AUTOLOAD {
     }
 
     if (wantarray) {
-        cluck "Returning Mock for `$cmd`\n" . Dumper($return), "\t" if ref $return ne 'ARRAY';
+        if ( !$return || !ref $return || ref $return ne 'ARRAY' ) {
+            confess "Returning Mock for `$cmd` with scalar value when expecting an array\n" . Dumper($return), "\t";
+        }
         return @$return;
     }
     else {
@@ -91,7 +94,7 @@ Mock::App::Git::Workflow::Repository - Mock of a git repository
 
 =head1 VERSION
 
-This documentation refers to Mock::App::Git::Workflow::Repository version 0.96007
+This documentation refers to Mock::App::Git::Workflow::Repository version 0.96008
 
 =head1 SYNOPSIS
 
